# Yet Another Repository on Github With Dotfiles (yargwid)

Influenced by [mathiasbyens/dotfiles](https://github.com/mathiasbynens/dotfiles).

![Screenshot of shell prompt](https://i.imgur.com/EkEtphC.png)

## Origins

My old dotfiles are in `old_dotfiles`. These were combined with dotfiles from Github user [mathiasbyens](https://github.com/mathiasbyens)
to result in this repository.

## Installation

### Using Git and the bootstrap script

Clone the repo to your desired directory:

```bash
git clone https://github.com/charlesreid1/yargwid.git && cd dotfiles && ./bootstrap.sh
```

To update, `cd` into your local `dotfiles` repository and then:

```bash
./bootstrap.sh
```

Alternatively, to update while avoiding the confirmation prompt:

```bash
set -- -f; ./bootstrap.sh
```

### Changing PATH

Modify the `~/.path` to use Bash syntax to modify the `$PATH` variable, e.g.,

```bash
export PATH="/usr/local/bin:$PATH"
```

### Git Identity and Etc

The `~/.extra` file is ignored by git, so you can put personal details there.
For example, set your git username/email:

```bash
# Git credentials
GIT_AUTHOR_NAME="XXXXXXXXX XXXXXXX"
GIT_COMMITTER_NAME="$GIT_AUTHOR_NAME"
git config --global user.name "$GIT_AUTHOR_NAME"
GIT_AUTHOR_EMAIL="xxxxxxxxx@xxxxxxxxxx.com"
GIT_COMMITTER_EMAIL="$GIT_AUTHOR_EMAIL"
git config --global user.email "$GIT_AUTHOR_EMAIL"
```

### Mac OS X

Set some Mac OS X specific settings by executing the contents of `.macos`:

```bash
./.macos
```

Now install Homebrew and various formulae:

```bash
./brew.sh
```

## References/Acknowledgements

Old material in the Yargwid repository [charlesreid1/yargwid (old_dotfiles dir)](https://github.com/charlesreid1/yargwid),
previously released under the GNU Public License v2.0, are being released and archived under the more permissive MIT License.
* [mathiasbyens/dotfiles](https://github.com/mathiasbynens/dotfiles).

Dotfile contents were a 50/50 mix: half dotfile habits accumulated over the decades, half Matthias's.
See LICENSE.matthias for license/acknowledgement of Matthias.

Listed by Matthias:
* @ptb and [his _OS X Lion Setup_ repository](https://github.com/ptb/Mac-OS-X-Lion-Setup)
* [Ben Alman](http://benalman.com/) and his [dotfiles repository](https://github.com/cowboy/dotfiles)
* [Chris Gerke](http://www.randomsquared.com/) and his [tutorial on creating an OS X SOE master image](http://chris-gerke.blogspot.com/2012/04/mac-osx-soe-master-image-day-7.html) + [_Insta_ repository](https://github.com/cgerke/Insta)
* [Cătălin Mariș](https://github.com/alrra) and his [dotfiles repository](https://github.com/alrra/dotfiles)
* [Gianni Chiappetta](http://gf3.ca/) for sharing his [amazing collection of dotfiles](https://github.com/gf3/dotfiles)
* [Jan Moesen](http://jan.moesen.nu/) and his [ancient `.bash_profile`](https://gist.github.com/1156154) + [shiny _tilde_ repository](https://github.com/janmoesen/tilde)
* [Lauri ‘Lri’ Ranta](http://lri.me/) for sharing [loads of hidden preferences](http://osxnotes.net/defaults.html)
* [Matijs Brinkhuis](http://hotfusion.nl/) and his [dotfiles repository](https://github.com/matijs/dotfiles)
* [Nicolas Gallagher](http://nicolasgallagher.com/) and his [dotfiles repository](https://github.com/necolas/dotfiles)
* [Sindre Sorhus](http://sindresorhus.com/)
* [Tom Ryder](https://sanctum.geek.nz/) and his [dotfiles repository](https://sanctum.geek.nz/cgit/dotfiles.git/about)
* [Kevin Suttle](http://kevinsuttle.com/) and his [dotfiles repository](https://github.com/kevinSuttle/dotfiles) and [OSXDefaults project](https://github.com/kevinSuttle/OSXDefaults), which aims to provide better documentation for [`~/.macos`](https://mths.be/macos)
* [Haralan Dobrev](http://hkdobrev.com/)
* anyone who [contributed a patch](https://github.com/mathiasbynens/dotfiles/contributors) or [made a helpful suggestion](https://github.com/mathiasbynens/dotfiles/issues)



Yet Another Repostiory on Github With Dotfiles

From the Bash man page, a brief explanation of some of the dot files:

	/bin/bash
	       The bash executable
	/etc/profile
	       The systemwide initialization file, executed for login shells
	~/.bash_profile
	       The personal initialization file, executed for login shells
	/etc/bashrc
	       The systemwide interactive shell initialization file, executed for all interactive shells, per-interactive-shell.
	~/.bashrc
	       The individual per-interactive-shell startup file
	~/.bash_logout
	       The individual login shell cleanup file, executed when a login shell exits
	~/.inputrc
	       Individual readline initialization file

