from fabric.api import *
from fabric.contrib.files import exists
from fabric.operations import local
import os
import os.path
import subprocess 

#################################
#
#
# fab help
#
#
################################

## http://zhar.net/projects/fccf/fabfile.py
## this still asks for a stupid password if we do any file operations like exists()
#env.hosts = ['localhost']
## workaround: use os lib



def help():
    """Get some help"""
    print "This is the fab file for charles reid dotfiles."
    print "Usage:"
    print ""
    print "     $ fab [machine name]"
    print ""
    print "Usage:"
    print ""
    print "     $ fab [machine name] "
    print ""
    print "     $ fab cronus # macbook os x"
    print "     $ fab rojo # charlesreid1.com"
    print "     $ fab morpheus # laptop thing 1"
    print "     $ fab basilisk # laptop thing 2"
    print "     $ fab jupiter # desktop"
    print "     $ fab quito # usb drive"
    print ""
    print "     $ [retired] fab mars"
    print "     $ [retired] fab saturn"
    print "     $ [retired] fab spaghettimonster"


def hello():
    """Just say hi"""
    print "J'allo J'allo, V'erld!"



def cronus():
    """instal dotfiles on cronus"""
    set_machine_name("cronus")
    doit()


def rojo():
    """instal dotfiles on rojo"""
    set_machine_name("rojo")
    doit()



def morpheus():
    """instal dotfiles on morpheus"""
    set_machine_name("morpheus")
    doit(am_root=True)


def basilisk():
    """instal dotfiles on basilisk"""
    set_machine_name("basilisk")
    doit(am_root=True)



def quito():
    """instal dotfiles on quito"""
    set_machine_name("quito")
    doit(am_root=True)



def set_machine_name(machine_name):
    env.machine_name = machine_name




# =======================================
# per-machine functions

def doit(am_root=False):

    # start by setting up vundle, to make sure vimrc doesn't break
    subprocess.call(['./scripts/setup_vundle.sh'])
    subprocess.call(['./scripts/setup_vimswap.sh'])

    tmpdir = "tmp"

    make_temp_directory(tmpdir)

    copy_machine_files(tmpdir,am_root=am_root)

    remove_temp_directory(tmpdir)

    install_scripts()




def make_temp_directory(tmpdir):
    clean(tmpdir)
    os.mkdir(tmpdir)


def remove_temp_directory(tmpdir):
    clean(tmpdir)


def install_scripts():
    local("cp -rf scripts/ ~/scripts/")


def copy_machine_files(tmpdir,am_root=False):

    mfers = []

    if am_root is False:

    	mfers = ['aliases',
    	        'bash_profile',
    	        'bashrc',
    	        'emacs',
    	        'gdbinit',
    	        'gitconfig',
    	        'inputrc',
    	        'motd',
    	        'profile',
    	        'tmux.conf',
    	        'vimrc',
    	        'vimrc.bundles',
    	        'vimrc.bundles.local',
    	        'viper',
    	        'vundle.sh']

    else:

        mfers = ['aliases',
                'bash_profile',
                'bashrc',
                'gdbinit',
                'gitconfig',
                'inputrc',
    	        'motd',
                'tmux.conf',
                'vimrc',
                'vimrc.bundles',
                'vimrc.bundles.local',
                'viper',
                'vundle.sh']

    for mf in mfers:

        if am_root:
             make_file_from_root(mf,tmpdir)
             backup(mf)
             copy(mf,tmpdir)
             done(mf)

        else:
             make_file_from_common(mf,tmpdir)
             backup(mf)
             copy(mf,tmpdir)
             done(mf)



def copy_machine_files_root(tmpdir,am_root):

    mfers = ['aliases',
            'bash_profile',
            'bashrc',
            'gdbinit',
            'gitconfig',
            'inputrc',
            'tmux.conf',
            'vimrc',
            'vimrc.bundles',
            'vimrc.bundles.local',
            'viper',
            'vundle.sh']

    for mf in mfers:

        if am_root:
             make_file_from_root(mf,tmpdir)
             backup(mf)
             copy(mf,tmpdir)
             done(mf)

        else:
             make_file_from_common(mf,tmpdir)
             backup(mf)
             copy(mf,tmpdir)
             done(mf)



def make_file_from_common(dotfile,tempdir):
    """Combine the common dotfile and the machine-specific dotfile to make the final dotfile"""

    common_file  = "common/"+dotfile
    machine_file = env.machine_name+"/"+dotfile+"."+env.machine_name
    output_file  = tempdir+"/"+dotfile

    # Use the common file, or make it blank
    if os.path.isfile(common_file):
        catcmd1 = "cat "+common_file+" > "+output_file
    else:
        catcmd1 = "cat /dev/null > "+output_file
    
    # Use the machine file, or don't
    if os.path.isfile(machine_file):
        catcmd2 = "cat "+machine_file+" "+output_file+" >> tempfile && mv -f tempfile "+output_file
    else:
        print "No machine file ",machine_file," found."
        catcmd2 = ""

    # Run the commands
    local(catcmd1)
    local(catcmd2)




def make_file_from_root(dotfile,tempdir):
    """Combine the root dotfile and the machine-specific dotfile to make the final dotfile"""

    root_file  = "root/"+dotfile
    machine_file = env.machine_name+"/"+dotfile+"."+env.machine_name
    output_file  = tempdir+"/"+dotfile

    # Use the root file, or make it blank
    if os.path.isfile(root_file):
        catcmd1 = "cat "+root_file+" > "+output_file
    else:
        catcmd1 = "cat /dev/null > "+output_file
    
    # Use the machine file, or don't
    if os.path.isfile(machine_file):
        catcmd2 = "cat "+machine_file+" "+output_file+" >> tempfile && mv -f tempfile "+output_file
    else:
        print "No machine file ",machine_file," found."
        catcmd2 = ""

    # Run the commands
    local(catcmd1)
    local(catcmd2)



def backup(dotfile):
    if os.path.isfile("~/."+dotfile):
        local("mv ~/."+dotfile+" ~/."+dotfile+".backup")


def copy(dotfile,tempdir):
    local("cp "+tempdir+"/"+dotfile+" ~/."+dotfile)


def clean(tempdir):
    local("rm -rf "+tempdir)


def done(dotfile):
    print "Finished installing file ~/."+dotfile
    print "(Old version is now at ~/."+dotfile+".backup)"
    print ""


